==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebTreeSelectionOptionsEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescription } from "./WebTreeSelectionOptionsEventDetailDescription";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTreeSelectionOptionsEventDetailDescriptionMetadata, _super);
    function WebTreeSelectionOptionsEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.b = function (a) {
        if (WebTreeSelectionOptionsEventDetailDescriptionMetadata.a == null) {
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.c(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
        if (a.g(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventDetail");
        a.item("NewSelection", "Collection:WebTreeItem:WebTreeItemCollection:WebTreeItem");
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.d = function (a) {
        WebTreeSelectionOptionsEventDetailDescriptionMetadata.b(a);
        a.u("WebTreeSelectionOptionsEventDetail", function () { return new WebTreeSelectionOptionsEventDetailDescription(); });
        a.t("WebTreeSelectionOptionsEventDetail", WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.$t = markType(WebTreeSelectionOptionsEventDetailDescriptionMetadata, 'WebTreeSelectionOptionsEventDetailDescriptionMetadata');
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventDetailDescriptionMetadata;
}(Base));
export { WebTreeSelectionOptionsEventDetailDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebTreeSelectionOptionsEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescription } from "./WebTreeSelectionOptionsEventDetailDescription";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTreeSelectionOptionsEventDetailDescriptionMetadata, _super);
    function WebTreeSelectionOptionsEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.b = function (a) {
        if (WebTreeSelectionOptionsEventDetailDescriptionMetadata.a == null) {
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.c(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
        if (a.j(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventDetail");
        a.item("NewSelection", "Collection:WebTreeItem:WebTreeItemCollection:WebTreeItem");
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.d = function (a) {
        WebTreeSelectionOptionsEventDetailDescriptionMetadata.b(a);
        a.aa("WebTreeSelectionOptionsEventDetail", function () { return new WebTreeSelectionOptionsEventDetailDescription(); });
        a.z("WebTreeSelectionOptionsEventDetail", WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.$t = markType(WebTreeSelectionOptionsEventDetailDescriptionMetadata, 'WebTreeSelectionOptionsEventDetailDescriptionMetadata');
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventDetailDescriptionMetadata;
}(Base));
export { WebTreeSelectionOptionsEventDetailDescriptionMetadata };
